@@ -1,15 +1,14 @@
 from particles import variables
 from particles import enc_mat, enc_vec, enc_tensor3
-from interactions import mono_assign, bi_assign, tri_assign
-from functions import reduce_add
-from circuit import circuit
+import interactions as assignemnts
+import functions
+import circuit
 import nn_layer
 import reusable_modules
 import interactions
 
 __all__ = [variables, enc_mat, enc_vec, enc_tensor3,
-           mono_assign, bi_assign, tri_assign,
-           reduce_add, nn_layer, reusable_modules,
+           assignemnts, functions, nn_layer, reusable_modules,
            interactions, circuit]
 
 import utils  # noqa
